@@ -67,13 +67,13 @@ async def statusdata2log(station, **data):
     try:
         installation = await cache_installation(station)
         if installation:
-            this_time = datetime.fromtimestamp(
-                data.get('BATT_MEM').get('TIMESTAMP')).astimezone(pytz.utc)
+            dt_gen_time = data.get('BATT_MEM',data.get("DOP", {})).get('TIMESTAMP')
+            this_time = datetime.fromtimestamp(dt_gen_time).astimezone(pytz.utc)
             data_log = {
                 'installation_ep': installation,
                 'dt_gen': this_time,
-                'batt_cap': data.get('BATT_MEM').get('BATT_CAPACITY', 0),
-                'remaining_mem': data.get('BATT_MEM').get('REMAINING_MEM', 0),
+                'batt_cap': data.get('BATT_MEM',{}).get('BATT_CAPACITY', 0),
+                'remaining_mem': data.get('BATT_MEM',{}).get('REMAINING_MEM', 0),
                 'hdop': data.get('DOP',{}).get('HDOP', 20),
                 'vdop': data.get('DOP',{}).get('VDOP', 20),
                 'pdop': data.get('DOP',{}).get('PDOP', 20),
@@ -82,7 +82,7 @@ async def statusdata2log(station, **data):
             return data_log
     except AttributeError as ae:
         gprint("Error de atributo")
-        print("No existe el atributo para el elemento", data, type(data), ae)
+        print("No existe el atributo para el elemento", station, data, type(data), ae)
     except ObjectDoesNotExist as e:
         print("Error al cargar instalaciones", e)
         raise e
@@ -101,7 +101,7 @@ class DjangoDataManager:
         self.engine = False
         self.pool = Pool(processes=4)
 
-    async def cycle_read_from_rmq(self, *args):
+    async def cycle_read_from_rmq(self, *args, **kwargs):
         engine = args[0]
         v = args[1]
         channels = args[2]
@@ -121,7 +121,7 @@ class DjangoDataManager:
             aux_set = None
             v += 1
             await asyncio.sleep(self.step)
-            return engine, v, channels
+            return [engine, v, channels], {}
         else:
             for channel, rmq in engine.items():
                 try:
@@ -134,15 +134,16 @@ class DjangoDataManager:
                     v = 0
                     channels.add(channel)
             await asyncio.sleep(self.step)
-            return engine, v, channels
+            return [engine, v, channels], {}
  
-    async def cycle_send_to_dj(self, *args):
+    async def cycle_send_to_dj(self, *args, **kwargs):
         """
         Leer la cola que recibe de rmq
         Enviar cada dato recibido de la cola y cargarlo
         """
         queue = args[0]
         data = []
+        await asyncio.sleep(1)
         try:
             #breakpoint()
             async for elem in read_async_queue(queue):
@@ -153,7 +154,6 @@ class DjangoDataManager:
                             elem.get("station"), **elem.get("data"))
                         if data_log:
                             try:
-                                #breakpoint()
                                 data.append(data_log)
                             except Exception as e:
                                 bprint("Creando lista de logs, error %s, LogUnidadGNSS create" % e)
@@ -168,7 +168,7 @@ class DjangoDataManager:
             print("Hubo una excepción al guardar los datos de LogGNSS")
             raise e
         data = []
-        return args
+        return args, kwargs
 
     def task_cycle(self):
         loop = asyncio.get_event_loop()
@@ -187,7 +187,7 @@ class DjangoDataManager:
 
         cycle_rmq_args = [rmq_engine, 0, channels]
         coroutine_future = coromask(self.cycle_read_from_rmq,
-                                    cycle_rmq_args,
+                                    cycle_rmq_args, {},
                                     simple_fargs_out)
         task = loop.create_task(coroutine_future)
         task.add_done_callback(
@@ -200,7 +200,7 @@ class DjangoDataManager:
         queue_dj = self.queue_set.get('status')
         cycle_dj_args = [queue_dj]
         coroutine_future = coromask(self.cycle_send_to_dj,
-                                    cycle_dj_args,
+                                    cycle_dj_args,{},
                                     simple_fargs_out)
         task = loop.create_task(coroutine_future)
         task.add_done_callback(
