@@ -4,13 +4,14 @@ from data_amqp import AMQPData
 class RMQEngine:
     def __init__(self, *args, **kwargs):
         self.__status = False
+        self.__queue_name = kwargs.get('queue_destiny')
         self.amqp = None
         if kwargs.get('amqp', False):
             try:
                 self.amqp_opt = kwargs['amqp']
                 self.amqp = AMQPData(**kwargs)
                 self.__status = True
-                self.__queue = kwargs.get('queue2ws')
+                self.__queue = kwargs.get(self.__queue_name)
                 self.__queue_active = False
             except Exception as e:
                 self.__status = False
@@ -30,3 +31,7 @@ class RMQEngine:
         loop, task = self.amqp.create_task(self.__queue, self.__queue_active)
         if not loop.is_running():
             loop.run_forever()
+
+    def connect(self):
+        if self.amqp:
+            self.amqp.connect()
